Lifecycle class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setter
isInitialized bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animationController({double? value, Duration? duration, Duration? reverseDuration, String? debugLabel, double lowerBound = 0.0, double upperBound = 1.0, AnimationBehavior animationBehavior = AnimationBehavior.normal, required TickerProvider vsync}) AnimationController
broadcastStreamController<T>({void onListen()?, void onCancel()?, bool sync = false}) StreamController<T>
effects(void callback()) → void
ensureActive() → void
ensureInitialized() → void
ensureNotDisposed() → void
listen<T>(Stream<T> stream, void listener(T it), {void onDone()?, void onError(Object error, StackTrace)?}) StreamSubscription<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void callback()) → void
onInit(void callback()) → void
periodicTimer(Duration duration, void callback(Timer)) Timer
scope() LifecycleScope
streamController<T>({void onListen()?, void onPause()?, void onResume()?, FutureOr<void> onCancel()?, bool sync = false}) StreamController<T>
timer(Duration duration, void callback()) → RestartableTimer
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited