LifecycleScope class

Implemented types

Constructors

LifecycleScope()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setteroverride
isInitialized bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animationController({double? value, Duration? duration, Duration? reverseDuration, String? debugLabel, double lowerBound = 0.0, double upperBound = 1.0, AnimationBehavior animationBehavior = AnimationBehavior.normal, required TickerProvider vsync}) AnimationController
override
broadcastStreamController<T>({void onListen()?, void onCancel()?, bool sync = false}) StreamController<T>
override
dispose() → void
effects(void callback()) → void
override
ensureActive() → void
override
ensureInitialized() → void
override
ensureNotDisposed() → void
override
init() → void
listen<T>(Stream<T> stream, void listener(T it), {void onDone()?, void onError(Object error, StackTrace)?}) StreamSubscription<T>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void callback()) → void
override
onInit(void callback()) → void
override
periodicTimer(Duration duration, void callback(Timer)) Timer
override
scope() LifecycleScope
override
streamController<T>({void onListen()?, void onPause()?, void onResume()?, FutureOr<void> onCancel()?, bool sync = false}) StreamController<T>
override
timer(Duration duration, void callback()) → RestartableTimer
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited