MutableSignal<T> class abstract interface

Implemented types
Available extensions

Constructors

MutableSignal(T value, {void onChange(T value)?, T set(T newValue)?, bool compare(T oldValue, T newValue) = _defaultCompare})
factory
MutableSignal.computed({required T getter(), required void setter(T value)})
factory
MutableSignal.late({void onChange(T value)?, T set(T newValue)?, bool compare(T oldValue, T newValue) = _defaultCompare})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>
no setterinherited
sync Stream<T>?
no setterinherited
value ↔ T
getter/setter pair

Methods

add(T element) → void

Available on MutableSignal<List<T>>, provided by the ListSignal extension

add(T element) → void

Available on MutableSignal<Set<T>>, provided by the SetSignal extension

addAll(Iterable<T> elements) → void

Available on MutableSignal<List<T>>, provided by the ListSignal extension

addAll(Map<K, V> entries) → void

Available on MutableSignal<Map<K, V>>, provided by the MapSignal extension

addAll(Iterable<T> elements) → void

Available on MutableSignal<Set<T>>, provided by the SetSignal extension

call() → T
inherited
clear() → void

Available on MutableSignal<List<T>>, provided by the ListSignal extension

clear() → void

Available on MutableSignal<Map<K, V>>, provided by the MapSignal extension

clear() → void

Available on MutableSignal<Set<T>>, provided by the SetSignal extension

insert(int index, T element) → void

Available on MutableSignal<List<T>>, provided by the ListSignal extension

listen(void onData(T value)?, {Function? onError, void onDone()?, bool? cancelOnError}) StreamSubscription<T>
inherited
mutate<X>(X mutator(T)) → X
mutateDelayed<X>(X mutator(T)) → X
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(T element) bool

Available on MutableSignal<List<T>>, provided by the ListSignal extension

remove(K key) → void

Available on MutableSignal<Map<K, V>>, provided by the MapSignal extension

remove(T element) → void

Available on MutableSignal<Set<T>>, provided by the SetSignal extension

removeAt(int index) → T

Available on MutableSignal<List<T>>, provided by the ListSignal extension

removeLast() → T

Available on MutableSignal<List<T>>, provided by the ListSignal extension

removeWhere(bool test(T element)) → void

Available on MutableSignal<List<T>>, provided by the ListSignal extension

setDelayed(T newValue) → void
toSignal() Signal<T>
toString() String
A string representation of this object.
inherited
update(T updater(T)) → void
watch(BuildContext context) → T
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator []=(K key, V value) → void

Available on MutableSignal<Map<K, V>>, provided by the MapSignal extension