Signal<T> class abstract interface

Implementers

Constructors

Signal(T value)
const
factory
Signal.computed(T compute(), {bool compare(T oldValue, T newValue) = _defaultCompare})
factory
Signal.create(T valueDelegate(), Stream<T> backingStream)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>
no setter
sync Stream<T>?
no setter

Methods

call() → T
listen(void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError}) StreamSubscription<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watch(BuildContext context) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited